#include <u.h>
#include <libc.h>
#include <bio.h>
#include <ctype.h>
#include <xml.h>
#include "defs.h"

char *Debug;
int Verbose;

char *
srch(Biobuf *bp, char *pre, char *post)
{
	char *s, *e, *str, *line;

	str = nil;
	while((line = Brdline(bp, '\n')) != nil){
		line[Blinelen(bp)-1] = 0;
		if((s = strstr(line, pre)) != nil){
			s += strlen(pre);
			if((e = strstr(s, post)) != nil){
				*e = 0;
				if((str = strdup(s)) == nil)
					sysfatal("No memory, %r");
				break;
			}
		}
	}
	return str;
}

void
prnt(Biobuf *bp, Xml *xp)
{
	int i;
	Elem *ep, *e1, *e2;
	char *fore, *given;
	struct {
		char *path;
		char *area;
	} Tab[] = {
		{ "/Report/Tablix5/Details_Collection", "office" },
		{ "/Report/Tablix4/Details3_Collection", "production" },
	};

	for(i = 0; i < nelem(Tab); i++){
		if((ep = xml_find(xp, xp->root, Tab[i].path)) == nil)
			continue;
		for(e1 = ep->child; e1; e1 = e1->next)
			if(e1->attrs && e1->attrs->value && e1->attrs->next->value){
				fore = e1->attrs->value;
				given = strchr(fore, ' ');
				*given++ = 0;

				Bprint(bp, "%s:%s:%s:%s:", trim(fore), trim(given), trim(e1->attrs->next->value), Tab[i].area);
			
				if((e2 = xml_look(xp->root, "/Report/Tablix7/Details1_Collection/Details1", "name1", e1->attrs->value)) != nil)
					if(e2->attrs && e2->attrs->next && e2->attrs->next->value)
						Bprint(bp, "%s", trim(e2->attrs->next->value));
				Bprint(bp, "\n");
			}
	}
}

void
usage(void)
{
	fprint(2, "usage: %s [-w webfs]\n", argv0);
	exits("usage");
}

void
main(int argc, char *argv[])
{
	Xml *xml;
	Sess *s;
	int fd;
	Biobuf in, out;
	char *path, *token, *webfs;

	Debug = nil;
	webfs = "/mnt/web";
	path = "Reports/Pages/Report.aspx?ItemPath=%%2fWho+Is+In";

	ARGBEGIN{
	case 'd':
		Debug = EARGF(usage());
		break;
	case 'v':
		Verbose++;
		break;
	case 'w':
		webfs = EARGF(usage());
		break;
	default:
		usage();
	}ARGEND;

	quotefmtinstall();

	if((s = mallocz(sizeof(Sess), 1)) == nil)
		sysfatal("No memory");

	if(dialweb(s, webfs, argv[0]) < 0)
		sysfatal("cannot get session to webfs");

	s->url = smprint("http://%s:4435", argv[0]);

	if((fd = exch(s, nil, path)) == -1)
		sysfatal("%s/%s cannot get info", s->url, path);
	Binit(&in, fd, OREAD);
	token = srch(&in, "\"ExportUrlBase\":\"/", "\",\"FixedTableId\"");
	Bterm(&in);
	close(fd);

	if((fd = exch(s, nil, "%sXML", token)) == -1)
		sysfatal("%s/%s cannot put info", s->url, path);

	Binit(&in, fd, OREAD);
	if((xml = xml_parse(&in, 1024, Fcrushwhite)) == nil)
		sysfatal("xml parse failed, %r");
	Bterm(&in);
	close(fd);

	Binit(&out, 1, OWRITE);
	prnt(&out, xml);
	Bterm(&out);
	exits(nil);
}
